@@ -552,7 +552,7 @@ abstract class ThemePlugin extends LazyLoadPlugin {
 		foreach ($this->options as $optionName => $optionConfig) {
 			$value = isset($values[$optionName]) ? $values[$optionName] : null;
 			// Convert values stored in the db to the type of the default value
-			if (!is_null($optionConfig->default)) {
+			if ($value !== null && $optionConfig->default !== null) {
 				switch (gettype($optionConfig->default)) {
 					case 'boolean':
 						$value = !$value || $value === 'false' ? false : true;
@@ -571,6 +571,16 @@ abstract class ThemePlugin extends LazyLoadPlugin {
 						break;
 				}
 			}
+			// If the value isn't null and it's a multilingual field, then we must ensure it's an array
+			if ($optionConfig->isMultilingual && $value !== null && !is_array($value)) {
+				try {
+					$value =  json_decode((string) $value, true, 512, JSON_THROW_ON_ERROR);
+				} catch (Exception $e) {
+					// FIXME: pkp/pkp-lib#6250 Remove after 3.3.x upgrade code is removed (see also pkp/pkp-lib#5772)
+					$value = unserialize($value);
+				}
+				$value = is_array($value) ? $value : [];
+			}
 			$return[$optionName] = $value;
 		}
 
